Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(495)

Unified Diff: remoting/protocol/channel_multiplexer.h

Issue 1143443003: Fix MessageReader to pass errors to the channel (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/protocol/channel_dispatcher_base.cc ('k') | remoting/protocol/channel_multiplexer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/protocol/channel_multiplexer.h
diff --git a/remoting/protocol/channel_multiplexer.h b/remoting/protocol/channel_multiplexer.h
index cb18d3377fdfddbbe7262ab9cc86d76bb6c4a781..c406d9b27030ef3a738e3a4f15897566702d264c 100644
--- a/remoting/protocol/channel_multiplexer.h
+++ b/remoting/protocol/channel_multiplexer.h
@@ -44,11 +44,12 @@ class ChannelMultiplexer : public StreamChannelFactory {
// Helper method used to create channels.
MuxChannel* GetOrCreateChannel(const std::string& name);
- // Error handling callback for |writer_|.
- void OnWriteFailed(int error);
+ // Error handling callback for |reader_| and |writer_|.
+ void OnBaseChannelError(int error);
- // Failed write notifier, queued asynchronously by OnWriteFailed().
- void NotifyWriteFailed(const std::string& name);
+ // Propagates base channel error to channel |name|, queued asynchronously by
+ // OnBaseChannelError().
+ void NotifyBaseChannelError(const std::string& name, int error);
// Callback for |reader_;
void OnIncomingPacket(scoped_ptr<MultiplexPacket> packet,
« no previous file with comments | « remoting/protocol/channel_dispatcher_base.cc ('k') | remoting/protocol/channel_multiplexer.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698